default_resources = {
        "chosen":{None:{'js':("jquery_chosen/chosen.jquery.js",),
                        'css':("jquery_chosen/chosen.css",
                                "chosen_bootstrap.css",)}
                 },
        "bootstrap":{None:{'js':('bootstrap.min.js',),
                           'css':('deform_bootstrap.css',)}},
        }
